@@ -1,3 +1,5 @@
+#define PERL_NO_GET_CONTEXT
+
 #include "EXTERN.h"
 #include "perl.h"
 #include "XSUB.h"
@@ -192,7 +194,8 @@ void ObjectPad_mop_class_add_ADJUST(pTHX_ ClassMeta *meta, CV *cv)
   av_push(meta->adjustblocks, (SV *)cv);
 }
 
-static bool mop_class_implements_role(ClassMeta *classmeta, ClassMeta *rolemeta)
+#define mop_class_implements_role(classmeta, rolemeta)  S_mop_class_implements_role(aTHX_ classmeta, rolemeta)
+static bool S_mop_class_implements_role(pTHX_ ClassMeta *classmeta, ClassMeta *rolemeta)
 {
   U32 i, n = av_count(classmeta->roles);
   RoleEmbedding **arr = (RoleEmbedding **)AvARRAY(classmeta->roles);
